Enum EncryptedFileHashAlgorithm
#[non_exhaustive]pub enum EncryptedFileHashAlgorithm {
Sha256,
}Expand description
An algorithm used to generate the hash of an EncryptedFile.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sha256
The SHA-256 algorithm
Implementations